@@ -1,30 +1,11 @@
-# --8<--8<--8<--8<--
-#
-# Copyright (C) 2015 Smithsonian Astrophysical Observatory
-#
-# This file is part of MooX-Cmd-ChainedOptions
-#
-# MooX-Cmd-ChainedOptions is free software: you can redistribute it
-# and/or modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation, either version 3 of
-# the License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# -->8-->8-->8-->8--
-
 package MooX::Cmd::ChainedOptions;
 
+# ABSTRACT: easily access options from higher up the command chain
+
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Import::Into;
 use Moo::Role     ();
@@ -33,11 +14,13 @@ use MooX::Options ();
 use MooX::Cmd::ChainedOptions::Role ();
 use List::Util qw/ first /;
 
+use namespace::clean;
+
 my %ROLE;
 
 sub import {
 
-    my $class  = shift;
+    shift;
     my $target = caller;
 
     unless ( $target->DOES( 'MooX::Cmd::Role' ) ) {
@@ -59,7 +42,7 @@ sub import {
     # parent class' command_base.  use the _build_command_base method
     # as it can be used as a class method; command_base is an object method
 
-    my ( $base, $pkg ) = $target =~ /^(.*)?::([^:]+)$/;
+    my ( $base ) = $target =~ /^(.*)?::([^:]+)$/;
     $base ||= '';
     my $parent = first { $base eq $_->_build_command_base } keys %ROLE;
 
@@ -78,8 +61,15 @@ sub import {
 
 1;
 
-
-__END__
+#
+# This file is part of MooX-Cmd-ChainedOptions
+#
+# This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+#
+# This is free software, licensed under:
+#
+#   The GNU General Public License, Version 3, June 2007
+#
 
 =pod
 
@@ -87,6 +77,10 @@ __END__
 
 MooX::Cmd::ChainedOptions - easily access options from higher up the command chain
 
+=head1 VERSION
+
+version 0.04
+
 =head1 SYNOPSIS
 
   # MyApp.pm : App Base Class
@@ -147,7 +141,6 @@ C<cmd_option> options via object attributes:
       print $self->subcmd_opt, "\n";
   }
 
-
 =head1 USAGE
 
 Simply
@@ -158,22 +151,107 @@ instead of
 
   use MooX::Options;
 
-Every layer in the application heirarchy (application class, command
+Every layer in the application hierarchy (application class, command
 class, sub-command class) must use B<MooX::Cmd::ChainedOptions>.  See
 the L</SYNOPSIS> for an example.
 
-=head1 COPYRIGHT AND LICENSE
+=head1 BUGS AND LIMITATIONS
 
-Copyright 2015 Smithsonian Astrophysical Observatory
-
-This software is released under the GNU General Public License.  You
-may find a copy at
-
-          http://www.gnu.org/licenses
-
-=cut
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://rt.cpan.org/Public/Dist/Display.html?Name=MooX-Cmd-ChainedOptions>.
 
 =head1 AUTHOR
 
-Diab Jerius (cpan:DJERIUS) <djerius@cfa.harvard.edu>
+Diab Jerius <djerius@cpan.org>
 
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by Smithsonian Astrophysical Observatory.
+
+This is free software, licensed under:
+
+  The GNU General Public License, Version 3, June 2007
+
+=cut
+
+__END__
+
+#pod =pod
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod   # MyApp.pm : App Base Class
+#pod   use Moo;
+#pod   use MooX::Cmd;
+#pod   use MooX::Cmd::ChainedOptions;
+#pod
+#pod   option app_opt => ( is => 'ro', format => 's', default => 'BASE' );
+#pod
+#pod   sub execute {
+#pod       print $_[0]->app_opt, "\n";
+#pod   }
+#pod
+#pod   # MyApp/Cmd/cmd.pm : Command Class
+#pod   package MyApp::Cmd::cmd;
+#pod   use Moo;
+#pod   use MooX::Cmd;
+#pod   use MooX::Cmd::ChainedOptions;
+#pod
+#pod   option cmd_opt => ( is => 'ro', format => 's', default => 'A' );
+#pod
+#pod   sub execute {
+#pod       print $_[0]->app_opt, "\n";
+#pod       print $_[0]->cmd_opt, "\n";
+#pod   }
+#pod
+#pod   # MyApp/Cmd/cmd/Cmd/subcmd.pm : Sub-Command Class
+#pod   package MyApp::Cmd::cmd::Cmd::subcmd;
+#pod   use Moo;
+#pod   use MooX::Cmd;
+#pod   use MooX::Cmd::ChainedOptions;
+#pod
+#pod   option subcmd_opt => ( is => 'ro', format => 's', default => 'B' );
+#pod
+#pod   sub execute {
+#pod       print $_[0]->app_opt, "\n";
+#pod       print $_[0]->cmd_opt, "\n";
+#pod       print $_[0]->subcmd_opt, "\n";
+#pod   }
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod For applications using L<MooX::Cmd> and L<MooX::Options>,
+#pod B<MooX::Cmd::ChainedOptions> transparently provides access to command
+#pod line options from further up the command chain.
+#pod
+#pod For example, if an application provides options at each level of the
+#pod command structure:
+#pod
+#pod   app --app-opt cmd --cmd-opt subcmd --subcmd-opt
+#pod
+#pod The B<subcmd> object will have direct access to the C<app_option> and
+#pod C<cmd_option> options via object attributes:
+#pod
+#pod   sub execute {
+#pod       print $self->app_opt, "\n";
+#pod       print $self->cmd_opt, "\n";
+#pod       print $self->subcmd_opt, "\n";
+#pod   }
+#pod
+#pod
+#pod =head1 USAGE
+#pod
+#pod Simply
+#pod
+#pod   use MooX::Cmd::ChainedOptions;
+#pod
+#pod instead of
+#pod
+#pod   use MooX::Options;
+#pod
+#pod Every layer in the application hierarchy (application class, command
+#pod class, sub-command class) must use B<MooX::Cmd::ChainedOptions>.  See
+#pod the L</SYNOPSIS> for an example.
+#pod
+#pod =head1 SEE ALSO
+#pod
